Para — Toy_Coronagraph 1.6.1 documentation

Skip to main content
`Ctrl`+`K`

# Para

Function to create parameter configuration python file

para.create_py_file(file_name, data)

  Creates a .py file with the given name and data.

  Parameters:

    - file_name (str) – The name of the .py file.

    - data (str) – The data to be included in the .py file.

  Returns:

    *.py

para.example_para()

  Create an example parameter file named ‘toycoronagraph_para.py’.

  The example parameter file includes settings related to the toy coronagraph simulation.

  Returns:

    toycoronagraph_para.py